@@ -11,7 +11,7 @@
 # Usage: sort < input.csv | uniq | makedb.rb > addr
 #
 
-# $Id: makedb.rb,v 1.6 2000/08/23 06:32:36 elca Exp $
+# $Id: makedb.rb,v 1.7 2002/06/08 16:27:31 elca Exp $
 
 print <<"__EOM__"
 
@@ -31,7 +31,7 @@ while gets
 
   l = $_.chop.split(",")
 
-  if l1 != l[1] && l1 != ""
+  if (l1 != l[1] && l1 != "") || (l0 != l[0] && l0 != "")
     print "\t\t],\n"
   end
   if l0 != l[0] && l0 != ""
